## $Id: pages.py 17627 2023-10-29 21:05:12Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
import grok
from waeup.kofa.browser.pages import (
    SessionConfigurationAddFormPage,
    SessionConfigurationManageFormPage,
    ConfigurationContainerManageFormPage,
    DatacenterPage, ExportCSVPage,
    CertificatePage, CertificateManageFormPage)
from waeup.kofa.browser.reports import ReportsContainerPage
from waeup.kofa.interfaces import IConfigurationContainer
from waeup.kofa.university.interfaces import ICertificate
from waeup.aaue.interfaces import (
    ICustomSessionConfiguration,
    ICustomSessionConfigurationAdd)

class CustomCertificatePage(CertificatePage):
    """Index page for certificates.
    """
    form_fields = grok.AutoFields(ICertificate).omit(
        'custom_float_2',
        'school_fee_1',
        'school_fee_2',
        'school_fee_3',
        'school_fee_4',
        'custom_textline_1',
        'custom_textline_2',
        )

class CustomCertificateManageFormPage(CertificateManageFormPage):
    """Manage the properties of a `Certificate` instance.
    """
    form_fields = grok.AutoFields(ICertificate).omit(
        'ratio',
        'custom_float_2',
        'school_fee_1',
        'school_fee_2',
        'school_fee_3',
        'school_fee_4',
        'custom_textline_1',
        'custom_textline_2',
        'code')

class CustomConfigurationContainerManageFormPage(
    ConfigurationContainerManageFormPage):

    form_fields = grok.AutoFields(IConfigurationContainer).omit(
        'frontpage_dict')
    form_fields['maintmode_enabled_by'].for_display = True

class CustomSessionConfigurationAddFormPage(SessionConfigurationAddFormPage):
    """Add a session configuration object to configuration container.
    """
    form_fields = grok.AutoFields(ICustomSessionConfigurationAdd)

class CustomSessionConfigurationManageFormPage(
    SessionConfigurationManageFormPage):
    """Manage session configuration object.
    """
    form_fields = grok.AutoFields(ICustomSessionConfiguration)

# Temporarily disable data export

#class CustomExportCSVPage(ExportCSVPage):

#    def update(self, CREATE=None, DISCARD=None, PURGE=None, exporter=None,
#               job_id=None, CANCEL=None):
#        if self.request.principal.id not in (
#            'admin', 'zope.manager', 'zope.mgr', 'amadin'):
#            self.flash('Data export has been temporarily disabled.',
#                       type='warning')
#            return self.redirect(self.url(self.context))
#        return super(CustomExportCSVPage,self).update(CREATE, DISCARD,
#            PURGE, exporter, job_id, CANCEL)

#class CustomReportsContainerPage(ReportsContainerPage):

#    def update(self, job_id=None, DISCARD=None, DOWNLOAD=None, PURGE=None):
#        if self.request.principal.id not in (
#            'admin', 'zope.manager', 'zope.mgr', 'amadin'):
#            self.flash('Reports have been temporarily disabled.',
#                       type='warning')
#            return self.redirect(self.application_url())
#        return super(CustomReportsContainerPage,self).update(
#            job_id, DISCARD, DOWNLOAD, PURGE)
